InfiniteQueryBehavior<T> class
Flutter port of React's infiniteQueryBehavior().
Replaces the default QueryOptions.queryFn-based fetch with page-aware logic:
direction == null→ refetch all existing pages in order (initial load or background refetch).direction == forward→ append a new page at the end.direction == backward→ prepend a new page at the start.
- Inheritance
-
- Object
- QueryBehavior<
List< T> > - InfiniteQueryBehavior
Constructors
- InfiniteQueryBehavior()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onFetch(
dynamic ctx, dynamic query) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited